@@ -1,4 +1,5 @@
 import re
+import json
 
 from qtpy import QT_VERSION
 from qtpy import QtCore
@@ -7,8 +8,7 @@ from qtpy import QtWidgets
 from qtpy.QtWidgets import QWidgetItem
 from xllabelme.logger import logger
 import xllabelme.utils
-from xllabelme.config.itemcfg import *
-from xllabelme.shape import ShapeExt
+from xllabelme.shape import Shape
 
 from pyxllib.gui.qt import get_input_widget, QHLine
 
@@ -409,16 +409,16 @@ class LabelDialogExt(DefaultLabelDialog):
         """ 增加布局项 """
         # 1 初始化
         self.initLayout()
-        showtext, hashtext, labelattr = shape.parser(mainwin)
+        labelcfg = mainwin.labelcfg
+        showtext, hashtext, labelattr = labelcfg.parse_shape(shape)
         if not labelattr:
             return
         layout = self.layout()
-        cfg = mainwin.labelcfg
 
         # 2 处理labelattr的场景
         # 2.1 原有标准控件调整
         self.labelList.hide()
-        self.edit.setEnabled(mainwin.label_editable.checked)
+        self.edit.setEnabled(labelcfg.cfg['editable'])
 
         # 2.2 封装添加每行控件的功能
         n_row = 1
@@ -428,14 +428,14 @@ class LabelDialogExt(DefaultLabelDialog):
 
             def edit_label(k, x):
                 """ 回调函数，控件修改值后，实时更新label """
-                self.edit.setText(shape.setLabelAttr(self.edit.text(), k, x))
+                self.edit.setText(labelcfg.set_label_attr(self.edit.text(), k, x))
                 self.setWindowModified(True)
 
             if k == 'label' and v and v['items'] is None and self.labelList.count():
                 # label 字段特殊处理
                 n = self.labelList.count()
                 texts = [self.labelList.item(i).text() for i in range(n)]
-                texts = [x for x in texts if (x[0] != '{' and x[-1] != '}')]
+                texts = [x for x in texts if (x and x[0] != '{' and x[-1] != '}')]
                 v = v.copy()
                 v['items'] = texts
                 add_row(k, v) if texts else add_row(k)
@@ -445,8 +445,11 @@ class LabelDialogExt(DefaultLabelDialog):
                 else:
                     items, cvt = None, None
 
-                w = get_input_widget(items, labelattr[k], valcvt=cvt,
-                                     text_changed=lambda x: edit_label(k, x))
+                cur_value = labelattr[k]
+                if cur_value is None:
+                    cur_value = 'None'
+                w = get_input_widget(items, cur_value, valcvt=cvt,
+                                     correct_changed=lambda x: edit_label(k, x))
                 layout.insertRow(n_row, k, w)
                 n_row += 1
 
@@ -454,25 +457,26 @@ class LabelDialogExt(DefaultLabelDialog):
         # 2.3.1 控件分三组：明确不显示，明确要显示，未在设定清单中
         # labelattr中的所有字段都应该要展示，但要优先展示配置项里指定的，再展示其他次要、衍生字段
         keys_group = [[], [], []]
-        for x in cfg.value:
+        for x in labelcfg.cfg['attrs']:
             k, s = x['key'], x['show']
             if k in labelattr:
                 keys_group[s].append(k)
-        cfgkeys = cfg.keys()
         for k in labelattr.keys():
-            if k not in cfgkeys:
+            if k not in labelcfg.keys:
                 keys_group[2].append(k)
         # 2.3.2
         for g in [1, 2, 0]:  # 展示每组的顺序
-            layout.insertRow(n_row, QHLine())  # 加分割线
-            n_row += 1
-            for k in keys_group[g]:
-                add_row(k, cfg.get(k, None))
+            if keys_group[g]:
+                layout.insertRow(n_row, QHLine())  # 加分割线
+                n_row += 1
+                for k in keys_group[g]:
+                    add_row(k, labelcfg.get(k, None))
         layout.insertRow(n_row, QHLine())
 
     def popUp2(self, shape, mainwin=None):
         # 1 初始化
         text, flags, group_id = shape.label, shape.flags, shape.group_id
+
         if self._fit_to_content["row"]:
             self.labelList.setMinimumHeight(
                 self.labelList.sizeHintForRow(0) * self.labelList.count() + 2
@@ -507,7 +511,7 @@ class LabelDialogExt(DefaultLabelDialog):
 
         # 3 保存、返回shape结果
         if self.exec_():
-            shape2 = ShapeExt()
+            shape2 = Shape()
             shape2.label = self.edit.text()
             shape2.flags = self.getFlags()
             shape2.group_id = self.getGroupId()
